@@ -17,15 +17,15 @@
  *
  */
 
-#ifndef _INTERFACE_H_
-#define _INTERFACE_H_
+#ifndef _PROCMAN_INTERFACE_H_
+#define _PROCMAN_INTERFACE_H_
 
 #include <procman.h>
 
 gint		get_sys_pane_pos (void);
-GtkWidget* 	create_main_window (ProcData *data);
-GtkWidget*	create_simple_view_dialog (ProcData *procdata);
+void		create_main_window (ProcData *data);
 void		toggle_infoview (ProcData *data);
 void		update_sensitivity (ProcData *data, gboolean sensitivity);
 void            do_popup_menu(ProcData *data, GdkEventButton *event);
-#endif
+
+#endif /* _PROCMAN_INTERFACE_H_ */
