@@ -23,6 +23,7 @@
 
 #include <signal.h>
 #include <string.h>
+#include <libgnomesu/libgnomesu.h>
 #include "procdialogs.h"
 #include "favorites.h"
 #include "proctable.h"
@@ -32,30 +33,18 @@
 #include "util.h"
 #include "load-graph.h"
 
-GtkWidget *renice_dialog = NULL;
-GtkWidget *prefs_dialog = NULL;
-gint new_nice_value = 0;
-int kill_signal = SIGTERM;
+static GtkWidget *renice_dialog = NULL;
+static GtkWidget *prefs_dialog = NULL;
+static gint new_nice_value = 0;
 
-static void
-cb_show_hide_message_toggled (GtkToggleButton *button, gpointer data)
-{
-	ProcData *procdata = data;
-	GConfClient *client = procdata->client;
-	gboolean toggle_state;
-	
-	toggle_state = gtk_toggle_button_get_active (button);
-
-	gconf_client_set_bool (client, "/apps/procman/hide_message", toggle_state, NULL);
-
-}
+/* public */ int kill_signal = SIGTERM;
 
 static void
 hide_dialog_button_pressed (GtkDialog *dialog, gint id, gpointer data)
 {
 	ProcData *procdata = data;
 	
-	if (id == 100) {
+	if (id == GTK_RESPONSE_OK) {
 		add_selected_to_blacklist (procdata);
 	}
 	
@@ -66,118 +55,39 @@ hide_dialog_button_pressed (GtkDialog *dialog, gint id, gpointer data)
 void
 procdialog_create_hide_dialog (ProcData *data)
 {
-	ProcData *procdata = data;
-	GtkWidget *messagebox1;
-	GtkWidget *dialog_vbox1, *vbox;
-	GtkWidget *hbox, *hbox1;
-	GtkWidget *dialog_action_area;
-  	GtkWidget *checkbutton1;
-	GtkWidget *button;
-	GtkWidget *image;
-	GtkWidget *label;
-	GtkWidget *align;
-	GtkWidget *icon;
-	gchar *header  = _("Are you sure you want to hide this process?");
-	gchar *message = _("If you hide a process, you can unhide it by selecting 'Hidden Processes' in the Edit menu.");
-	gchar *title;
-		  			
-  	messagebox1 = gtk_dialog_new ();
-	
-	gtk_window_set_title (GTK_WINDOW (messagebox1), "");
-	gtk_window_set_resizable (GTK_WINDOW (messagebox1), FALSE);
-	gtk_window_set_modal (GTK_WINDOW (messagebox1), TRUE);
-	
-	gtk_dialog_set_has_separator (GTK_DIALOG (messagebox1), FALSE);
-	gtk_container_set_border_width (GTK_CONTAINER (messagebox1), 5);
-	
-	dialog_vbox1 = GTK_DIALOG (messagebox1)->vbox;
-	gtk_box_set_spacing (GTK_BOX (dialog_vbox1), 14);
+       ProcData *procdata = data;
+       GtkWidget *hide_alert_dialog;
+       gchar *message;
 
-	hbox = gtk_hbox_new (FALSE, 12);
-	gtk_box_pack_start (GTK_BOX (dialog_vbox1), hbox, FALSE, FALSE, 0);
-	gtk_container_set_border_width (GTK_CONTAINER (hbox), 5);
-	gtk_widget_show (hbox);
+       /*translators: primary alert message*/
+       message = g_strdup_printf (_("Hide the selected process?"));
+       hide_alert_dialog = gtk_message_dialog_new (GTK_WINDOW (procdata->app),
+						   GTK_DIALOG_MODAL | GTK_DIALOG_DESTROY_WITH_PARENT,
+						   GTK_MESSAGE_WARNING,
+						   GTK_BUTTONS_NONE,
+						   message);
+       g_free (message);
 
-	image = gtk_image_new_from_stock ("gtk-dialog-warning", GTK_ICON_SIZE_DIALOG);
-	gtk_box_pack_start (GTK_BOX (hbox), image, FALSE, FALSE, 0);
-	gtk_widget_show (image);
+       /*translators: secondary alert messagex*/
+       message = g_strdup_printf (_("Hidden processes are no longer visible "
+				    "in the processes list. You can re-enable "
+				    "them selecting the \"Hidden Processes\" "
+				    "entry in the View menu."));
+       gtk_message_dialog_format_secondary_text (GTK_MESSAGE_DIALOG (hide_alert_dialog),
+						 message);
+       g_free (message);
+
+       gtk_dialog_add_buttons (GTK_DIALOG (hide_alert_dialog),
+                               GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL,
+                               _("_Hide Process"), GTK_RESPONSE_OK,
+                               NULL);
+       gtk_dialog_set_default_response (GTK_DIALOG (hide_alert_dialog),
+                                        GTK_RESPONSE_OK);
 	
-	vbox = gtk_vbox_new (FALSE, 12);
-	gtk_box_pack_start (GTK_BOX (hbox), vbox, TRUE, TRUE, 0);
-	gtk_widget_show (vbox);
-	
-	title = g_strconcat ("<b>", _(header), "</b>", NULL);
-	label = gtk_label_new (title);  
-	gtk_box_pack_start (GTK_BOX (vbox), label, FALSE, FALSE, 0);
-	gtk_label_set_use_markup (GTK_LABEL (label), TRUE);
-	gtk_label_set_justify (GTK_LABEL (label), GTK_JUSTIFY_LEFT);
-	gtk_label_set_line_wrap (GTK_LABEL (label), TRUE);
-	gtk_misc_set_alignment (GTK_MISC (label), 0, 0.5);
-	gtk_widget_show (label);
-	g_free (title);
-	
-	label = gtk_label_new (_(message));
-	gtk_box_pack_start (GTK_BOX (vbox), label, FALSE, FALSE, 0);
-	gtk_label_set_justify (GTK_LABEL (label), GTK_JUSTIFY_LEFT);
-	gtk_label_set_line_wrap (GTK_LABEL (label), TRUE);
-	gtk_misc_set_alignment (GTK_MISC (label), 0, 0.5);
-	gtk_widget_show (label);
-	
-	dialog_action_area = GTK_DIALOG (messagebox1)->action_area;
-	gtk_button_box_set_layout (GTK_BUTTON_BOX (dialog_action_area), GTK_BUTTONBOX_END);
-
-	button = gtk_button_new_from_stock ("gtk-cancel");
-  	gtk_widget_show (button);
-  	gtk_dialog_add_action_widget (GTK_DIALOG (messagebox1), button, GTK_RESPONSE_CANCEL);
-	GTK_WIDGET_SET_FLAGS (button, GTK_CAN_DEFAULT);
-
-  	hbox1 = gtk_hbox_new (FALSE, 0);
-  	gtk_widget_show (hbox1);
-  	gtk_box_pack_end (GTK_BOX (vbox), hbox1, TRUE, TRUE, 0);
-
-  	checkbutton1 = gtk_check_button_new_with_mnemonic (_("_Show this dialog next time"));
-  	gtk_widget_show (checkbutton1);
-  	gtk_box_pack_end (GTK_BOX (hbox1), checkbutton1, FALSE, FALSE, 0);
-    	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (checkbutton1), TRUE);
-
-	button = gtk_button_new ();
-	GTK_WIDGET_SET_FLAGS (button, GTK_CAN_DEFAULT);
-		
-	align = gtk_alignment_new (0.5, 0.5, 0.0, 0.0);
-	gtk_container_add (GTK_CONTAINER (button), align);
-		
-	hbox = gtk_hbox_new (FALSE, 2);
-	gtk_container_add (GTK_CONTAINER (align), hbox);
-
-	icon = gtk_image_new_from_stock (GTK_STOCK_OK, GTK_ICON_SIZE_BUTTON);
-	gtk_box_pack_start (GTK_BOX (hbox), icon, FALSE, FALSE, 0);
+       g_signal_connect (G_OBJECT (hide_alert_dialog), "response",
+			 G_CALLBACK (hide_dialog_button_pressed), procdata);
   	
-	label = gtk_label_new_with_mnemonic (_("_Hide Process"));
-	gtk_label_set_mnemonic_widget (GTK_LABEL (label), button);
-	gtk_box_pack_end (GTK_BOX (hbox), label, FALSE, FALSE, 0);
-
-	gtk_dialog_add_action_widget (GTK_DIALOG (messagebox1), button, 100);
-  	gtk_dialog_set_default_response (GTK_DIALOG (messagebox1), 100);
-	
-  	g_signal_connect (G_OBJECT (checkbutton1), "toggled",
-                      	  G_CALLBACK (cb_show_hide_message_toggled), procdata);
-        g_signal_connect (G_OBJECT (messagebox1), "response",
-        		  G_CALLBACK (hide_dialog_button_pressed), procdata);
-  	
-  	gtk_widget_show_all (messagebox1);
-
-}
-
-static void
-cb_show_kill_warning_toggled (GtkToggleButton *button, gpointer data)
-{
-	ProcData *procdata = data;
-	GConfClient *client = procdata->client;
-	gboolean toggle_state;
-	
-	toggle_state = gtk_toggle_button_get_active (button);
-	
-	gconf_client_set_bool (client, "/apps/procman/kill_dialog", toggle_state, NULL);	
+       gtk_widget_show_all (hide_alert_dialog);
 
 }
 
@@ -188,7 +98,7 @@ kill_dialog_button_pressed (GtkDialog *dialog, gint id, gpointer data)
 	
 	gtk_widget_destroy (GTK_WIDGET (dialog));
 
-	if (id == 100) 
+	if (id == GTK_RESPONSE_OK) 
 		kill_process (procdata, kill_signal);		
 }
 
@@ -196,125 +106,54 @@ void
 procdialog_create_kill_dialog (ProcData *data, int signal)
 {
 	ProcData *procdata = data;
-	GtkWidget *messagebox1;
-	GtkWidget *dialog_vbox1, *vbox;
-  	GtkWidget *hbox1, *hbox2;
-  	GtkWidget *checkbutton1;
-	GtkWidget *dialog_action_area;
-	GtkWidget *button;
-	GtkWidget *align;
-	GtkWidget *label;
-	GtkWidget *icon;
-	GtkWidget *image;
-  	gchar *text, *title;
-	gchar *header, *message;
-  	
+	GtkWidget *kill_alert_dialog;
+	gchar *primary, *secondary, *button_text;
   	kill_signal = signal;
   	
   	if (signal == SIGKILL) {
-  		header = _("Are you sure you want to kill this process?");
-		message = _("If you kill a process, unsaved data will be lost.");
-  		text = _("_Kill Process");
+                /*translators: primary alert message*/
+  		primary = _("Kill the selected process?");
+		/*translators: secondary alert message*/
+		secondary = _("Killing a process, you could destroy your data, "
+			      "break the working session or create a security risk. "
+			      "Only misbehaving processes should be killed.");
+  		button_text = _("_Kill Process");
 		  	}
   	else {
-  		header = _("Are you sure you want to end this process?");
-		message = _("If you end a process, unsaved data will be lost.");
-  		text = _("_End Process");
+                /*translators: primary alert message*/
+                primary = _("End the selected process?");
+	        /*translators: secondary alert message*/
+                secondary = _("Ending a process, you could destroy your data, "
+		              "break the working session or create a security risk. "
+			      "Only misbehaving processes should be ended.");
+                button_text = _("_End Process");
   	}
 
-	messagebox1 = gtk_dialog_new ();
-  	
-  	gtk_window_set_title (GTK_WINDOW (messagebox1), "");
-  	gtk_window_set_modal (GTK_WINDOW (messagebox1), TRUE);
-  	gtk_window_set_resizable (GTK_WINDOW (messagebox1), FALSE);
-  
-	gtk_dialog_set_has_separator (GTK_DIALOG (messagebox1), FALSE);
-	gtk_container_set_border_width (GTK_CONTAINER (messagebox1), 5);
-	
-    	dialog_vbox1 = GTK_DIALOG (messagebox1)->vbox;
-    	gtk_box_set_spacing (GTK_BOX (dialog_vbox1), 14);
-    	
-	hbox1 = gtk_hbox_new (FALSE, 12);
-	gtk_box_pack_start (GTK_BOX (dialog_vbox1), hbox1, FALSE, FALSE, 0);
-	gtk_container_set_border_width (GTK_CONTAINER (hbox1), 5);
-	gtk_widget_show (hbox1);
+	kill_alert_dialog = gtk_message_dialog_new (GTK_WINDOW (procdata->app),
+						    GTK_DIALOG_MODAL | GTK_DIALOG_DESTROY_WITH_PARENT,
+						    GTK_MESSAGE_WARNING,
+						    GTK_BUTTONS_NONE,
+						    _(primary));
+	gtk_message_dialog_format_secondary_text (GTK_MESSAGE_DIALOG (kill_alert_dialog),
+						  _(secondary));
 
-	image = gtk_image_new_from_stock ("gtk-dialog-warning", GTK_ICON_SIZE_DIALOG);
-	gtk_box_pack_start (GTK_BOX (hbox1), image, FALSE, FALSE, 0);
-	gtk_widget_show (image);
-	
-	vbox = gtk_vbox_new (FALSE, 12);
-	gtk_box_pack_start (GTK_BOX (hbox1), vbox, TRUE, TRUE, 0);
-	gtk_widget_show (vbox);
-	
-	title = g_strconcat ("<b>", _(header), "</b>", NULL);
-	label = gtk_label_new (title);  
-	gtk_box_pack_start (GTK_BOX (vbox), label, FALSE, FALSE, 0);
-	gtk_label_set_use_markup (GTK_LABEL (label), TRUE);
-	gtk_label_set_justify (GTK_LABEL (label), GTK_JUSTIFY_LEFT);
-	gtk_label_set_line_wrap (GTK_LABEL (label), TRUE);
-	gtk_misc_set_alignment (GTK_MISC (label), 0, 0.5);
-	gtk_widget_show (label);
-	g_free (title);
-	
-	label = gtk_label_new (_(message));
-	gtk_box_pack_start (GTK_BOX (vbox), label, FALSE, FALSE, 0);
-	gtk_label_set_justify (GTK_LABEL (label), GTK_JUSTIFY_LEFT);
-	gtk_label_set_line_wrap (GTK_LABEL (label), TRUE);
-	gtk_misc_set_alignment (GTK_MISC (label), 0, 0.5);
-	gtk_widget_show (label);
-	
-	dialog_action_area = GTK_DIALOG (messagebox1)->action_area;
-	gtk_button_box_set_layout (GTK_BUTTON_BOX (dialog_action_area), GTK_BUTTONBOX_END);
+	gtk_dialog_add_buttons (GTK_DIALOG (kill_alert_dialog),
+				GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL,
+				_(button_text), GTK_RESPONSE_OK,
+				NULL);
 
-	button = gtk_button_new_from_stock ("gtk-cancel");
-  	gtk_widget_show (button);
-  	gtk_dialog_add_action_widget (GTK_DIALOG (messagebox1), button, GTK_RESPONSE_CANCEL);
-	GTK_WIDGET_SET_FLAGS (button, GTK_CAN_DEFAULT);
+	gtk_dialog_set_default_response (GTK_DIALOG (kill_alert_dialog),
+					 GTK_RESPONSE_CANCEL);
 
-  	hbox2 = gtk_hbox_new (FALSE, 0);
-  	gtk_widget_show (hbox2);
-  	gtk_box_pack_end (GTK_BOX (vbox), hbox2, TRUE, TRUE, 0);
-
-  	checkbutton1 = gtk_check_button_new_with_mnemonic (_("_Show this dialog next time"));
-  	gtk_widget_show (checkbutton1);
-  	gtk_box_pack_end (GTK_BOX (hbox2), checkbutton1, FALSE, FALSE, 0);
-    	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (checkbutton1), TRUE);
-
-	button = gtk_button_new ();
-	GTK_WIDGET_SET_FLAGS (button, GTK_CAN_DEFAULT);
-		
-	align = gtk_alignment_new (0.5, 0.5, 0.0, 0.0);
-	gtk_container_add (GTK_CONTAINER (button), align);
-		
-	hbox1 = gtk_hbox_new (FALSE, 2);
-	gtk_container_add (GTK_CONTAINER (align), hbox1);
-
-	icon = gtk_image_new_from_stock (GTK_STOCK_OK, GTK_ICON_SIZE_BUTTON);
-	gtk_box_pack_start (GTK_BOX (hbox1), icon, FALSE, FALSE, 0);
-
-	label = gtk_label_new_with_mnemonic (_(text));
-	gtk_label_set_mnemonic_widget (GTK_LABEL (label), button);
-	gtk_box_pack_end (GTK_BOX (hbox1), label, FALSE, FALSE, 0);
-
-	gtk_dialog_add_action_widget (GTK_DIALOG (messagebox1), button, 100);
-  	gtk_dialog_set_default_response (GTK_DIALOG (messagebox1), 100);	
-					    
-  	g_signal_connect (G_OBJECT (checkbutton1), "toggled",
-                      	  G_CALLBACK (cb_show_kill_warning_toggled),
-                      	  procdata);
-        g_signal_connect (G_OBJECT (messagebox1), "response",
+        g_signal_connect (G_OBJECT (kill_alert_dialog), "response",
         		  G_CALLBACK (kill_dialog_button_pressed), procdata);
         
-        gtk_widget_show_all (messagebox1);
-        
-        
+        gtk_widget_show_all (kill_alert_dialog);
 }
 
 static gchar *
 get_nice_level (gint nice)
 {
-
 	if (nice < -7)
 		return _("(Very High Priority)");
 	else if (nice < -2)
@@ -325,7 +164,6 @@ get_nice_level (gint nice)
 		return _("(Low Priority)");
 	else
 		return _("(Very Low Priority)");
-	
 }
 
 static void
@@ -571,31 +409,6 @@ update_disks_update_interval (GtkWidget *widget, GdkEventFocus *event, gpointer
 	return FALSE;
 }
 
-static void		
-bg_color_changed (GnomeColorPicker *cp, guint r, guint g, guint b,
-		  guint a, gpointer data)
-{
-	ProcData *procdata = data;
-	GConfClient *client = procdata->client;
-	gchar *color;
-	
-	color = g_strdup_printf("#%04x%04x%04x", r, g, b);
-	gconf_client_set_string (client, "/apps/procman/bg_color", color, NULL);
-	g_free (color);
-}
-
-static void		
-frame_color_changed (GnomeColorPicker *cp, guint r, guint g, guint b,
-		  guint a, gpointer data)
-{
-	ProcData *procdata = data;
-	GConfClient *client = procdata->client;
-	gchar *color;
-	
-	color = g_strdup_printf("#%04x%04x%04x", r, g, b);
-	gconf_client_set_string (client, "/apps/procman/frame_color", color, NULL);
-	g_free (color);
-}
 
 static void
 proc_field_toggled (GtkToggleButton *button, gpointer data)
@@ -650,6 +463,7 @@ create_proc_field_page (ProcData *procdata)
 	gtk_scrolled_window_set_policy (GTK_SCROLLED_WINDOW (scrolled),
                                   	GTK_POLICY_AUTOMATIC,
                                   	GTK_POLICY_AUTOMATIC);
+	gtk_scrolled_window_set_shadow_type (GTK_SCROLLED_WINDOW (scrolled), GTK_SHADOW_IN);
         gtk_box_pack_start (GTK_BOX (vbox), scrolled, TRUE, TRUE, 0);
         
         model = gtk_list_store_new (3, G_TYPE_BOOLEAN, G_TYPE_STRING, G_TYPE_POINTER);	
@@ -731,25 +545,26 @@ procdialog_create_preferences_dialog (ProcData *procdata)
 		
 	size = gtk_size_group_new (GTK_SIZE_GROUP_HORIZONTAL);
 	
-	dialog = gtk_dialog_new_with_buttons (_("Preferences"), NULL,
+	dialog = gtk_dialog_new_with_buttons (_("System Monitor Preferences"),
+					      GTK_WINDOW (procdata->app),
 					      GTK_DIALOG_DESTROY_WITH_PARENT,
 					      GTK_STOCK_CLOSE, GTK_RESPONSE_CLOSE,
 					      NULL);
 	gtk_window_set_default_size (GTK_WINDOW (dialog), 400,  375);
-	gtk_container_set_border_width (GTK_CONTAINER (dialog), 5);
+	gtk_container_set_border_width (GTK_CONTAINER (dialog), 6);
 	gtk_dialog_set_has_separator (GTK_DIALOG (dialog), FALSE);
 	prefs_dialog = dialog;
 	
 	main_vbox = GTK_DIALOG (dialog)->vbox;
-	gtk_box_set_spacing (GTK_BOX (main_vbox), 2);
+	gtk_box_set_spacing (GTK_BOX (main_vbox), 12);
 	
 	notebook = gtk_notebook_new ();
-	gtk_container_set_border_width (GTK_CONTAINER (notebook), 5);
+	gtk_container_set_border_width (GTK_CONTAINER (notebook), 6);
 	gtk_box_pack_start (GTK_BOX (main_vbox), notebook, TRUE, TRUE, 0);
 	
 	proc_box = gtk_vbox_new (FALSE, 18);
 	gtk_container_set_border_width (GTK_CONTAINER (proc_box), 12);
-	tab_label = gtk_label_new_with_mnemonic (_("Process Listing"));
+	tab_label = gtk_label_new (_("Processes"));
 	gtk_widget_show (tab_label);
 	gtk_notebook_append_page (GTK_NOTEBOOK (notebook), proc_box, tab_label);
 	
@@ -798,7 +613,7 @@ procdialog_create_preferences_dialog (ProcData *procdata)
 	hbox2 = gtk_hbox_new (FALSE, 6);
 	gtk_box_pack_start (GTK_BOX (vbox2), hbox2, FALSE, FALSE, 0);
 		
-	check_button = gtk_check_button_new_with_mnemonic (_("Show warning dialog when ending or _killing processes"));
+	check_button = gtk_check_button_new_with_mnemonic (_("Alert before ending or _killing processes"));
 	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (check_button), 
 				      procdata->config.show_kill_warning);
 	g_signal_connect (G_OBJECT (check_button), "toggled",
@@ -808,7 +623,7 @@ procdialog_create_preferences_dialog (ProcData *procdata)
 	hbox2 = gtk_hbox_new (FALSE, 6);
 	gtk_box_pack_start (GTK_BOX (vbox2), hbox2, FALSE, FALSE, 0);
 	
-	check_button = gtk_check_button_new_with_mnemonic (_("Show warning dialog when _hiding processes"));
+	check_button = gtk_check_button_new_with_mnemonic (_("Alert before _hiding processes"));
 	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (check_button), 
 				    procdata->config.show_hide_message);
 	g_signal_connect (G_OBJECT (check_button), "toggled",
@@ -836,7 +651,7 @@ procdialog_create_preferences_dialog (ProcData *procdata)
 	
 	sys_box = gtk_vbox_new (FALSE, 12);
 	gtk_container_set_border_width (GTK_CONTAINER (sys_box), 12);
-	tab_label = gtk_label_new_with_mnemonic (_("Resource Monitor"));
+	tab_label = gtk_label_new (_("Resources"));
 	gtk_widget_show (tab_label);
 	gtk_notebook_append_page (GTK_NOTEBOOK (notebook), sys_box, tab_label);
 	
@@ -897,7 +712,7 @@ procdialog_create_preferences_dialog (ProcData *procdata)
 				    procdata->config.bg_color.green,
 				    procdata->config.bg_color.blue, 0);
 	g_signal_connect (G_OBJECT (color_picker), "color_set",
-			          G_CALLBACK (bg_color_changed), procdata);
+			          G_CALLBACK (cb_bg_color_changed), procdata);
 	gtk_box_pack_start (GTK_BOX (hbox2), color_picker,TRUE, TRUE, 0);
 	gtk_label_set_mnemonic_widget (GTK_LABEL (label), color_picker);
 	gtk_widget_show (color_picker);
@@ -916,7 +731,7 @@ procdialog_create_preferences_dialog (ProcData *procdata)
 				    procdata->config.frame_color.green,
 				    procdata->config.frame_color.blue, 0);
 	g_signal_connect (G_OBJECT (color_picker), "color_set",
-			    G_CALLBACK (frame_color_changed), procdata);	  
+			    G_CALLBACK (cb_frame_color_changed), procdata);	  
 	gtk_box_pack_start (GTK_BOX (hbox2), color_picker, TRUE, TRUE, 0);	
 	gtk_label_set_mnemonic_widget (GTK_LABEL (label), color_picker);
 	gtk_widget_show (color_picker);
@@ -990,101 +805,13 @@ entry_activate_cb (GtkEntry *entry, gpointer data)
 void procdialog_create_root_password_dialog (gint type, ProcData *procdata, gint pid, 
 					     gint extra_value, gchar *text)
 {
-	GtkWidget *dialog;
-	GtkWidget *error_dialog;
-	GtkWidget *main_vbox;
-	GtkWidget *hbox;
-	GtkWidget *entry;
-	GtkWidget *label;
-	gchar *title = NULL, *button_label;
 	gchar *command;
-	gchar *password, *blank;
-	gint retval;
-
-	if (type == 0) {
-		if (extra_value == SIGKILL) {
-			title = g_strdup (_("Kill Process"));
-			button_label = g_strdup (_("_Kill Process"));
-		}
-		else {
-			title = g_strdup (_("End Process"));
-			button_label = g_strdup (_("_End Process"));
-		}
-	}
-	else {
-		title = g_strdup (_("Change Priority"));
-		button_label = g_strdup (_("Change _Priority"));
-	}
-		
-	dialog = gtk_dialog_new_with_buttons (title, NULL, GTK_DIALOG_DESTROY_WITH_PARENT,
-					      GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL,
-					      button_label, 100,
-					      NULL);
-	
-	main_vbox = GTK_DIALOG (dialog)->vbox;
-	
-	label = gtk_label_new (_(text));
-	gtk_label_set_line_wrap (GTK_LABEL (label), TRUE);
-	gtk_misc_set_padding (GTK_MISC (label), GNOME_PAD, 2 * GNOME_PAD);
-	gtk_box_pack_start (GTK_BOX (main_vbox), label, FALSE, FALSE, 0);
-	
-	hbox = gtk_hbox_new (FALSE, 0);
-	gtk_container_set_border_width (GTK_CONTAINER (hbox), GNOME_PAD_SMALL);
-	gtk_box_pack_start (GTK_BOX (main_vbox), hbox, FALSE, FALSE, 0);
-	
-	label = gtk_label_new (_("Root Password :"));
-	gtk_misc_set_padding (GTK_MISC (label), GNOME_PAD_SMALL, 0);
-	gtk_box_pack_start (GTK_BOX (hbox), label, TRUE, FALSE, 0);
-	
-	entry = gtk_entry_new ();
-	gtk_entry_set_visibility (GTK_ENTRY (entry), FALSE);
-	gtk_box_pack_start (GTK_BOX (hbox), entry, TRUE, FALSE, 0);
-	g_signal_connect (G_OBJECT (entry), "activate",
-			  G_CALLBACK (entry_activate_cb), dialog);
-		
-	gtk_widget_show_all (main_vbox);
-	
-	gtk_dialog_set_default_response (GTK_DIALOG (dialog), GTK_RESPONSE_CANCEL);
-	gtk_widget_grab_focus (entry);
-		
-	g_free (title);	
-	g_free (button_label);
-	
-	retval = gtk_dialog_run (GTK_DIALOG (dialog));
-	gtk_widget_hide (dialog);
-	
-	if (retval == 100) {
-		password = gtk_editable_get_chars (GTK_EDITABLE (entry), 0, -1);
-		
-		if (!password)
-			password = "";
-		blank = g_strdup (password);
-		if (strlen (blank))
-			memset (blank, ' ', strlen (blank));
-			
-		gtk_entry_set_text (GTK_ENTRY (entry), blank);
-		gtk_entry_set_text (GTK_ENTRY (entry), "");
-		g_free (blank);
-		
-		if (type == 0)
-			command = g_strdup_printf ("kill -s %d %d", extra_value, pid);
-		else
-			command = g_strdup_printf ("renice %d %d", extra_value, pid);
-			
-		if (su_run_with_password (command, password) == -1) {
-			error_dialog = gtk_message_dialog_new (NULL,
-							       GTK_DIALOG_DESTROY_WITH_PARENT,
-                                  			       GTK_MESSAGE_ERROR,
-                                  			       GTK_BUTTONS_OK,
-                                  			       "%s",
-                                  			      _("Wrong Password.")); 
-			gtk_dialog_run (GTK_DIALOG (error_dialog));
-			gtk_widget_destroy (error_dialog);
-		}
-		g_free (command);
-		
-	}
-	gtk_widget_destroy (dialog);
 
+	if (type == 0)
+		command = g_strdup_printf ("kill -s %d %d", extra_value, pid);
+	else
+		command = g_strdup_printf ("renice %d %d", extra_value, pid);
+	gnomesu_exec (command);
+	g_free (command);
 }
 
